﻿using System.IO;
using System.IO.IsolatedStorage;
using System.Security.Cryptography;
using System.Text;

namespace DotNetApp
{
    public static class SecurityHelper
    {
        public static void WriteSetting(string key, string value)
        {
            if (value != null)
            {
                byte[] unProtectedValue = Encoding.UTF8.GetBytes(value);
                byte[] protectedValue = ProtectedData.Protect(unProtectedValue, null);

                IsolatedStorageSettings.ApplicationSettings[key] = protectedValue;
            }
        }

        public static string ReadSetting(string key, bool isKeyRemovedAfterRead = false)
        {
            string value = null;

            if (IsolatedStorageSettings.ApplicationSettings.Contains(key))
            {
                byte[] protectedValue = (byte[])IsolatedStorageSettings.ApplicationSettings[key];
                byte[] unProtectedValue = ProtectedData.Unprotect(protectedValue, null);

                value = Encoding.UTF8.GetString(unProtectedValue, 0, unProtectedValue.Length);

                if (isKeyRemovedAfterRead)
                {
                    IsolatedStorageSettings.ApplicationSettings.Remove(key);
                }
            }

            return value;
        }

        public static void WriteFile(string fileName, string content)
        {
            byte[] contentInBytes = Encoding.UTF8.GetBytes(content);

            WriteFile(fileName, contentInBytes);
        }

        public static void WriteFile(string fileName, byte[] content)
        {
            IsolatedStorageFile isolatedStorageFile = IsolatedStorageFile.GetUserStoreForApplication();

            string directoryName = Path.GetDirectoryName(fileName);

            if (!string.IsNullOrEmpty(directoryName))
            {
                isolatedStorageFile.CreateDirectory(directoryName);
            }

            using (IsolatedStorageFileStream isolatedStorageFileStream = isolatedStorageFile.OpenFile(fileName, FileMode.Create))
            {
                byte[] protectedContent = ProtectedData.Protect(content, null);

                isolatedStorageFileStream.Write(protectedContent, 0, protectedContent.Length);
            }
        }

        public static string ReadFile(string fileName)
        {
            byte[] contentInBytes;
            ReadFile(fileName, out contentInBytes);

            return Encoding.UTF8.GetString(contentInBytes, 0, contentInBytes.Length);
        }

        public static void ReadFile(string fileName, out byte[] content)
        {
            IsolatedStorageFile isolatedStorageFile = IsolatedStorageFile.GetUserStoreForApplication();

            using (IsolatedStorageFileStream isolatedStorageFileStream = isolatedStorageFile.OpenFile(fileName, FileMode.Open))
            {
                byte[] protectedContent = new byte[isolatedStorageFileStream.Length];
                isolatedStorageFileStream.Read(protectedContent, 0, (int)isolatedStorageFileStream.Length);

                content = ProtectedData.Unprotect(protectedContent, null);
            }
        }
    }
}